..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Digital repositories
====================

.. todo::

   Write this section

What is a digital repository?
-----------------------------

Record keeping
--------------

Persistent identifiers
----------------------

Metadata
--------

Data
----

Open Archival Information Systems (OAIS)
----------------------------------------
